---
title: "{{ cookiecutter.project_title }}"
---


This is the website home page generated by `index.qmd` under the root directory. For authoring with `.qmd` files, see Quarto's [website](https://quarto.org/).

Edit `index.qmd` and re-run `astrodown dev --render-quarto` to apply changes.




